@@ -10,7 +10,7 @@
 #' The model is fit with a different magnitude by treatment (as a factor,
 #' if given) and a random slope by subject (if given).  A minimum of
 #' \code{min.points} is required to fit the model.
-#' 
+#'
 #' @param \dots See \code{\link{pk.tss.data.prep}}
 #' @param check See \code{\link{pk.tss.data.prep}}
 #' @param min.points The minimum number of points required for the fit
@@ -27,12 +27,10 @@
 #' Estimating Time to Steady State with Examples from Phase 1 Studies.
 #' AAPS Journal 10(1):141-7. doi:10.1208/s12248-008-9014-y
 #' @export
-#' @importFrom nlme intervals lme
-#' @importFrom stats confint coef glm
 pk.tss.stepwise.linear <- function(...,
                                    min.points=3, level=0.95, verbose=FALSE,
                                    check=TRUE) {
-  ## Check inputs
+  # Check inputs
   modeldata <- pk.tss.data.prep(..., check=check)
   if (is.factor(min.points) |
       !is.numeric(min.points))
@@ -54,32 +52,33 @@ pk.tss.stepwise.linear <- function(...,
   if (level <= 0 | level >= 1) {
     stop("level must be between 0 and 1, exclusive")
   }
-  ## Confirm that we may have sufficient data to complete the
-  ## modeling.  Because of the variety of methods used for estimating
-  ## time to steady-state, assurance that we have enough data is more
-  ## simply determined by model convergence.
+  # Confirm that we may have sufficient data to complete the
+  # modeling.  Because of the variety of methods used for estimating
+  # time to steady-state, assurance that we have enough data is more
+  # simply determined by model convergence.
   if (length(unique(modeldata$time)) < min.points) {
     warning("After removing non-dosing time points, insufficient data remains for tss calculation")
     return(NA)
   }
-  ## Assign treatment if given and with multiple levels
+  # Assign treatment if given and with multiple levels
   formula.to.fit <- stats::as.formula("conc~time")
   if ("treatment" %in% names(modeldata))
     formula.to.fit <- stats::as.formula("conc~time+treatment")
-  ## Ensure that the dosing times are in order to allow us to kick
-  ## them out in order.
+  # Ensure that the dosing times are in order to allow us to kick
+  # them out in order.
   remaining.time <- sort(unique(modeldata$time))
   ret <- NA
   while (is.na(ret) &
          (length(remaining.time) >= min.points)) {
-    if (verbose)
-      cat("Trying ", min(remaining.time, na.rm=TRUE), "\n")
+    if (verbose) {
+      message("Trying ", min(remaining.time, na.rm=TRUE))
+    }
     try({
-      ## Try to make the model
-      current.interval <- 
+      # Try to make the model
+      current.interval <-
         if ("subject" %in% names(modeldata)) {
-          ## If we have a subject column, try to fit a linear
-          ## mixed-effects model.
+          # If we have a subject column, try to fit a linear
+          # mixed-effects model.
           current.model <-
             nlme::lme(
               formula.to.fit,
@@ -87,23 +86,26 @@ pk.tss.stepwise.linear <- function(...,
               data=modeldata[modeldata$time >= min(remaining.time),,drop=FALSE])
           nlme::intervals(current.model, level=level, which="fixed")$fixed["time",]
         } else {
-          ## If we do not have a subject column, fit a linear model.
+          # If we do not have a subject column, fit a linear model.
           current.model <-
             stats::glm(
               formula.to.fit,
               data=modeldata[modeldata$time >= min(remaining.time),,drop=FALSE])
-          ## There is no intervals function for glm, so build one
+          # There is no intervals function for glm, so build one
           ci <- as.vector(stats::confint(current.model, "time", level=level))
           c(ci[1], stats::coef(current.model)[["time"]], ci[2])
         }
-      if (verbose)
-        cat(sprintf("Current interval %g [%g, %g]",
-                    current.interval[2],
-                    current.interval[1],
-                    current.interval[3]))
-      ## If the signs of the upper and lower bounds of the slope of
-      ## the confidence interval for time are different, then we have
-      ## a non-significant slope.  A non-significant slope indicates steady-state.
+      if (verbose) {
+        message(
+          sprintf("Current interval %g [%g, %g]",
+                  current.interval[2],
+                  current.interval[1],
+                  current.interval[3])
+        )
+      }
+      # If the signs of the upper and lower bounds of the slope of
+      # the confidence interval for time are different, then we have
+      # a non-significant slope.  A non-significant slope indicates steady-state.
       if (sign(current.interval[1]) != sign(current.interval[3]))
         ret <- min(remaining.time, na.rm=TRUE)
     }, silent=!verbose)
