@@ -1,8 +1,6 @@
-context("Half-life")
-
 test_that("pk.calc.half.life", {
-  ## Confirm that half-life is correctly calculated with a simple
-  ## exponential decay
+  # Confirm that half-life is correctly calculated with a simple
+  # exponential decay
   v1 <-
     pk.calc.half.life(conc=c(1, 0.5, 0.25),
                       time=c(0, 1, 2),
@@ -11,8 +9,8 @@ test_that("pk.calc.half.life", {
                       adj.r.squared.factor=0.0001)$half.life
   expect_equal(v1, 1)
 
-  ## Ensure that when input data is not checked, the code works
-  ## correctly.
+  # Ensure that when input data is not checked, the code works
+  # correctly.
   v2 <-
     pk.calc.half.life(conc=c(1, 0.5, 0.25),
                       time=c(0, 1, 2),
@@ -23,14 +21,14 @@ test_that("pk.calc.half.life", {
                  
   expect_equal(v2, 1)
 
-  ## Ensure that min.hl.points is respected
+  # Ensure that min.hl.points is respected
   expect_warning(pk.calc.half.life(conc=c(1, 0.5, 0.25),
                                    time=c(0, 1, 2),
                                    min.hl.points=4),
                  regexp="Too few points for half-life calculation")
 
-  ## Ensure that when there are more than one best models by adjusted
-  ## r-squared, the one with the most points is used.
+  # Ensure that when there are more than one best models by adjusted
+  # r-squared, the one with the most points is used.
   expect_warning(
     expect_equal(pk.calc.half.life(conc=c(1, 0.5, 0.25, 0.1251),
                                    time=c(0, 1, 2, 3),
@@ -41,7 +39,7 @@ test_that("pk.calc.half.life", {
                  1.000346,
                  tolerance=0.0001))
 
-  ## Ensure that the allow.tmax.in.half.life parameter is followed
+  # Ensure that the allow.tmax.in.half.life parameter is followed
   expect_equal(pk.calc.half.life(conc=c(1, 0.5, 0.25, 0.1251),
                                  time=c(0, 1, 2, 3),
                                  min.hl.points=3,
@@ -60,8 +58,8 @@ test_that("pk.calc.half.life", {
                  tolerance=0.00001))
   
 
-  ## Make sure that when tmax and tlast are given that they are
-  ## automatically included and not recalculated
+  # Make sure that when tmax and tlast are given that they are
+  # automatically included and not recalculated
   expect_equal(pk.calc.half.life(conc=c(1, 0.5, 0.25, 0.1251),
                                  time=c(0, 1, 2, 3),
                                  min.hl.points=3,
@@ -79,7 +77,7 @@ test_that("pk.calc.half.life", {
                           half.life=1.000346,
                           span.ratio=2.998962),
                tolerance=0.0001)
-  ## It only gives tlast or tmax if you don't give them as inputs.
+  # It only gives tlast or tmax if you don't give them as inputs.
   expect_equal(pk.calc.half.life(conc=c(1, 0.5, 0.25, 0.1251),
                                  time=c(0, 1, 2, 3),
                                  min.hl.points=3,
@@ -176,8 +174,8 @@ test_that("half-life manual point selection", {
 })
 
 test_that("two-point half-life succeeds (fix #114)", {
-  expect_equal(
-    expect_warning(
+  expect_warning(expect_warning(
+    expect_equal(
       pk.calc.half.life(
         conc=c(1, 0.5),
         time=c(0, 1),
@@ -185,19 +183,20 @@ test_that("two-point half-life succeeds (fix #114)", {
         allow.tmax.in.half.life=TRUE,
         check=FALSE
       ),
-      regexp="n must be > 2 for adj.r.squared"
+      data.frame(
+        lambda.z=log(2),
+        r.squared=1,
+        adj.r.squared=NA_real_,
+        lambda.z.time.first=0,
+        lambda.z.n.points=2,
+        clast.pred=0.5,
+        half.life=1,
+        span.ratio=1,
+        tmax=0,
+        tlast=1
+      )
     ),
-    data.frame(
-      lambda.z=log(2),
-      r.squared=1,
-      adj.r.squared=NA_real_,
-      lambda.z.time.first=0,
-      lambda.z.n.points=2,
-      clast.pred=0.5,
-      half.life=1,
-      span.ratio=1,
-      tmax=0,
-      tlast=1
-    )
+    class = "pknca_halflife_2points"),
+    class = "pknca_adjr2_2points"
   )
-})
\ No newline at end of file
+})
